==> node-typescript_5.0.4%2Bds1.orig.tar.xz: TypeScript-5.0.4/tests/baselines/reference/tscWatch/resolutionCache/ignores-changes-in-node_modules-that-start-with-dot/watch-without-configFile.js <==
Input::
//// [/a/lib/lib.d.ts]
/// <reference no-default-lib="true"/>
interface Boolean {}
interface Function {}
interface CallableFunction {}
interface NewableFunction {}
interface IArguments {}
interface Number { toExponential: any; }
interface Object {}
interface RegExp {}
interface String { charAt: any; }
interface Array<T> { length: number; [n: number]: T; }

//// [/user/username/projects/myproject/test.ts]
import { x } from "somemodule";

//// [/user/username/projects/myproject/node_modules/somemodule/index.d.ts]
export const x = 10;

//// [/user/username/projects/myproject/tsconfig.json]
{}


/a/lib/tsc.js --w /user/username/projects/myproject/test.ts
Output::
>> Screen clear
[[90m12:00:27 AM[0m] Starting compilation in watch mode...

[[90m12:00:30 AM[0m] Found 0 errors. Watching for file changes.



Program root files: ["/user/username/projects/myproject/test.ts"]
Program options: {"watch":true}
Program structureReused: Not
Program files::
/a/lib/lib.d.ts
/user/username/projects/myproject/node_modules/somemodule/index.d.ts
/user/username/projects/myproject/test.ts

Semantic diagnostics in builder refreshed for::
/a/lib/lib.d.ts
/user/username/projects/myproject/node_modules/somemodule/index.d.ts
/user/username/projects/myproject/test.ts

Shape signatures in builder refreshed for::
/a/lib/lib.d.ts (used version)
/user/username/projects/myproject/node_modules/somemodule/index.d.ts (used version)
/user/username/projects/myproject/test.ts (used version)

PolledWatches::

FsWatches::
/user/username/projects/myproject/test.ts:
  {}
/user/username/projects/myproject/node_modules/somemodule/index.d.ts:
  {}
/a/lib/lib.d.ts:
  {}

FsWatchesRecursive::
/user:
  {}

exitCode:: ExitStatus.undefined

//// [/user/username/projects/myproject/test.js]
"use strict";
Object.defineProperty(exports, "__esModule", { value: true });



Change:: npm install file and folder that start with '.'

Input::
//// [/user/username/projects/myproject/node_modules/.cache/babel-loader/89c02171edab901b9926470ba6d5677e.ts]
{"something":10}


Output::

PolledWatches::

FsWatches::
/user/username/projects/myproject/test.ts:
  {}
/user/username/projects/myproject/node_modules/somemodule/index.d.ts:
  {}
/a/lib/lib.d.ts:
  {}

FsWatchesRecursive::
/user:
  {}

exitCode:: ExitStatus.undefined

==> node-typescript_5.1.6%2Bds1.orig.tar.xz: TypeScript-5.1.6/tests/baselines/reference/tscWatch/resolutionCache/ignores-changes-in-node_modules-that-start-with-dot/watch-without-configFile.js <==
currentDirectory:: / useCaseSensitiveFileNames: false
Input::
//// [/a/lib/lib.d.ts]
/// <reference no-default-lib="true"/>
interface Boolean {}
interface Function {}
interface CallableFunction {}
interface NewableFunction {}
interface IArguments {}
interface Number { toExponential: any; }
interface Object {}
interface RegExp {}
interface String { charAt: any; }
interface Array<T> { length: number; [n: number]: T; }

//// [/user/username/projects/myproject/test.ts]
import { x } from "somemodule";

//// [/user/username/projects/myproject/node_modules/somemodule/index.d.ts]
export const x = 10;

//// [/user/username/projects/myproject/tsconfig.json]
{}


/a/lib/tsc.js --w /user/username/projects/myproject/test.ts
Output::
>> Screen clear
[[90m12:00:27 AM[0m] Starting compilation in watch mode...

[[90m12:00:30 AM[0m] Found 0 errors. Watching for file changes.



Program root files: ["/user/username/projects/myproject/test.ts"]
Program options: {"watch":true}
Program structureReused: Not
Program files::
/a/lib/lib.d.ts
/user/username/projects/myproject/node_modules/somemodule/index.d.ts
/user/username/projects/myproject/test.ts

Semantic diagnostics in builder refreshed for::
/a/lib/lib.d.ts
/user/username/projects/myproject/node_modules/somemodule/index.d.ts
/user/username/projects/myproject/test.ts

Shape signatures in builder refreshed for::
/a/lib/lib.d.ts (used version)
/user/username/projects/myproject/node_modules/somemodule/index.d.ts (used version)
/user/username/projects/myproject/test.ts (used version)

FsWatches::
/user/username/projects/myproject/test.ts: *new*
  {}
/user/username/projects/myproject/node_modules/somemodule/index.d.ts: *new*
  {}
/a/lib/lib.d.ts: *new*
  {}

FsWatchesRecursive::
/user/username/projects: *new*
  {}

exitCode:: ExitStatus.undefined

//// [/user/username/projects/myproject/test.js]
"use strict";
Object.defineProperty(exports, "__esModule", { value: true });



Change:: npm install file and folder that start with '.'

Input::
//// [/user/username/projects/myproject/node_modules/.cache/babel-loader/89c02171edab901b9926470ba6d5677e.ts]
{"something":10}


Timeout callback:: count: 0
Immedidate callback:: count: 0
Output::

exitCode:: ExitStatus.undefined
